summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/spl-cast.cc
diff options
context:
space:
mode:
authorDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-09-24 09:50:51 -0500
committerDavid Lawrence Ramsey <dolorous@users.sourceforge.net>2009-09-24 09:50:51 -0500
commit42c04eb9ff6b36614de58eb3017735071f710ce2 (patch)
treed38334c7d4483e086750961285273a73cdd7af20 /crawl-ref/source/spl-cast.cc
parent3ed0f149cfa5f8e40ccb554c550415ac63c6895b (diff)
downloadcrawl-ref-42c04eb9ff6b36614de58eb3017735071f710ce2.tar.gz
crawl-ref-42c04eb9ff6b36614de58eb3017735071f710ce2.zip
Add more spelling fixes.
Diffstat (limited to 'crawl-ref/source/spl-cast.cc')
-rw-r--r--crawl-ref/source/spl-cast.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/crawl-ref/source/spl-cast.cc b/crawl-ref/source/spl-cast.cc
index dfe3135ca8..f436f3c059 100644
--- a/crawl-ref/source/spl-cast.cc
+++ b/crawl-ref/source/spl-cast.cc
@@ -1168,11 +1168,11 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
int potion = -1;
// XXX: This handles only some of the cases where spells need targeting...
// there are others that do their own that will be missed by this
// (and thus will not properly ESC without cost because of it).
// Hopefully, those will eventually be fixed. -- bwr
- if ((flags & SPFLAG_TARGETING_MASK) && spell != SPELL_PORTAL_PROJECTILE)
+ if ((flags & SPFLAG_TARGETTING_MASK) && spell != SPELL_PORTAL_PROJECTILE)
{
targ_mode_type targ =
(testbits(flags, SPFLAG_HELPFUL) ? TARG_FRIEND : TARG_ENEMY);
@@ -1180,7 +1180,7 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
if (testbits(flags, SPFLAG_NEUTRAL))
targ = TARG_ANY;
- targeting_type dir =
+ targetting_type dir =
( (spell == SPELL_APPORTATION) ? DIR_TARGET_OBJECT :
testbits(flags, SPFLAG_TARGET) ? DIR_TARGET :
testbits(flags, SPFLAG_GRID) ? DIR_TARGET :
@@ -1168,11 +1168,11 @@ spret_type your_spells(spell_type spell, int powc, bool allow_fail)
int potion = -1;
- // XXX: This handles only some of the cases where spells need targeting...
+ // XXX: This handles only some of the cases where spells need targetting...
// there are others that do their own that will be missed by this
// (and thus will not properly ESC without cost because of it).